require "regxlib/version"

module Regxlib

  class Error < StandardError; end

  # [START] Regxlib::Username ###########
  class Username

    # Regxlib::Username.standard
    def self.standard
      /\A[a-zA-Z1234567890]+[a-zA-Z-_1234567890]+[a-zA-Z1234567890]\z/i
    end

    # Regxlib::Username.standard_nonum
    def self.standard_nonum
      /\A[a-zA-Z]+[a-zA-Z\-_]+[a-zA]\z/i
    end

    # Regxlib::Username.strict
    def self.strict
      /\A[a-zA-Z1234567890]+[a-zA-Z1234567890]+[a-zA-Z1234567890]\z/i
    end

    # Regxlib::Username.strict_no_num
    def self.strict_nonum
      /\A[a-zA-Z]+[a-zA-Z]+[a-zA-Z]\z/i
    end

  end
  # [START] Regxlib::Username ###########

  # [START] Regxlib::Email ###########
  class Email

    # Regxlib::Email.multi
    def self.multi
      /\A[\w+-.]+@[a-z\d\-.]+\.(
      [i]+[o]
      |[c]+[o]+[m]
      |[m]+[a]+[i]+[l]
      |[c]+[o]+\.[a]+[u]
      |[c]+[o]+\.[u]+[k]
      |[c]+[o]+\.[u]+[s]
      |[c]+[o]+\.[b]+[r]
      |[c]+[o]+\.[d]+[k]
      |[c]+[o]+\.[e]+[u]
      |[c]+[o]+\.[f]+[i]
      |[c]+[o]+\.[f]+[r]
      |[c]+[o]+\.[d]+[e]
      |[c]+[o]+\.[g]+[r]
      |[c]+[o]+\.[i]+[n]
      |[c]+[o]+\.[i]+[e]
      |[c]+[o]+\.[i]+[t]
      |[c]+[o]+\.[n]+[z]
      |[c]+[o]+\.[n]+[o]
      |[c]+[o]+\.[e]+[s]
      |[c]+[o]+\.[s]+[e]
      )+\z/i
    end
    # Regxlib::Email.standard
    def self.standard
      /\A[\w+-.]+@[a-z\d\-.]+\.[a-z]+\z/i
    end

    # Regxlib::Email.org
    def self.org
      /\A[\w+-.]+@[a-z\d\-.]+\.[o]+[r]+[g]+\z/i
    end

    # Regxlib::Email.edu
    def self.edu
      /\A[\w+-.]+@[a-z\d\-.]+\.[e]+[d]+[u]+\z/i
    end

    # Regxlib::Email.co_uk_com
    def self.co_uk_com
      /\A[\w+-.]+@[a-z\d\-.]+\.([c]+[o]+\.[u]+[k]|[c]+[o]+[m])+\z/i
    end

    # Regxlib::Email.com
    def self.com
      /\A[\w+-.]+@[a-z\d\-.]+\.[c]+[o]+[m]+\z/i
    end

    # Regxlib::Email.co.uk
    def self.co_uk
      /\A[\w+-.]+@[a-z\d\-.]+\.[c]+[o]+\.[u]+[k]+\z/i
    end
    
  end
  # [END] Regxlib::Email ##############

  # [START] Regxlib::String ##############
  class String

    # Regxlib::String.char_nospace
    def self.char_nospace
      /\A[a-zA-Z]+\z/i
    end

  end
  # [END] Regxlib::String ##############

end